/*
 * Arduino 2 / MOTOSHIELD
 * Receive Data from XBee/Arduino 1
 * ----------------------------------
 * Author: jeromeabel.net
 * Licence: GNU/GPL3
 * Date: 2014-09
 * Art project: http://jeromeabel.net/art/patatas-de-goma
 */
 
#include <Tone.h>
#include <SerialCommand.h>

// ---- PATATAS ---- //
Tone tone1;
SerialCommand sCmd;

int pinTone = 3; // Klaxon tone > pin 6 of the shield
int pinPwm = 9; // Klaxon intensity > pin 6 of the shield
int pinPhPwm = 5; // Phare
long periodePWM = 1000; //max duty cycle
long data;

// ---- TIMER ---- //
// TIMER 0 : 5/6 (PHARE)
// TIMER 1 : 9/10 OCR1A/OCR1B (KLAXON / PWM : 10KHZ)
// TIMER 2 : 3/11 (TONE)
// !! TCCR2A error with Leonardo !! because of the Tone library

void setup() {
  // ENABLE
  pinMode(8,OUTPUT);
  pinMode(12,OUTPUT); // > pin 9
  digitalWrite(8,HIGH);
  digitalWrite(12,HIGH);
  
  // 16Mhz(horloge)/2/1(prescaler) : 8Mhz
  TCCR1A = 0b10100000;
  TCCR1B = 0b00010001;
  ICR1 = periodePWM; // 8Mhz/PeriodePWM = ... Hz
  
  // PINS
  pinMode(pinPwm, OUTPUT);
  pinMode(pinPhPwm, OUTPUT);   
  tone1.begin(pinTone);
  
  Serial.begin(57600);
  
  // SERIAL COMMAND
  sCmd.addCommand("kt", kt); // klaxon tone
  sCmd.addCommand("kp", kp); // klaxon intensite pwm %
  sCmd.addCommand("ph", ph); // phare pwm
  sCmd.addCommand("cy", cy); // max duty cycle
  
  digitalWrite(pinPhPwm,HIGH);
  delay(1000);
  digitalWrite(pinPhPwm,LOW);
}

void loop() {  
   sCmd.readSerial();
}

// ---- COMMANDS ---- //
void kp() {
  char *arg;
  arg = sCmd.next();
  if (arg != NULL) {
    data = atoi(arg);
    //Serial.println(data * periodePWM * 0.01);
    OCR1A = data * periodePWM * 0.01;
  }
}

void kt() {
  char *arg;
  arg = sCmd.next(); 
  if (arg != NULL) {
    //Serial.println(atoi(arg)*4);
    tone1.play(atoi(arg) * 4);
  }
}

void ph() {
  char *arg;
  arg = sCmd.next();
  if (arg != NULL) {
    //Serial.println(atoi(arg));
    analogWrite(pinPhPwm, atoi(arg));
  }
}

void cy() {
  char *arg;
  arg = sCmd.next();
  if (arg != NULL) {
    data = atoi(arg);
    periodePWM = atoi(arg) * 10;
    //OCR1A = data * periodePWM * 0.01;
  }
}

